Leopard class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate → int
The audio sample rate required by Leopard
no setter
version → String
Leopard version string
no setter

Methods

delete() → Future<void>
Frees memory that was allocated for Leopard
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(List<int>? frame) → Future<LeopardTranscript>
Process a frame of pcm audio with the speech-to-text engine.
processFile(String path) → Future<LeopardTranscript>
Processes given audio data and returns its transcription.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(String accessKey, String modelPath, {String? device, bool enableAutomaticPunctuation = false, bool enableDiarization = false}) → Future<Leopard>
Static creator for initializing Leopard
getAvailableDevices() → Future<List<String>>
Lists all available devices that Leopard can use for inference. Entries in the list can be used as the device argument when initializing Leopard.