LeopardWord class

Constructors

LeopardWord(String? _word, double startSec, double endSec, double confidence, int speakerTag)

Properties

confidence → double
final
endSec → double
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speakerTag → int
final
startSec → double
final
word → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited